@@ -7,6 +7,7 @@ import json
 import logging
 import re
 import typing as t
+import xml.etree.ElementTree as ET
 from enum import Enum
 from pathlib import Path
 
@@ -21,7 +22,7 @@ from arguebuf.models.node import AtomNode, Attack, Node, Rephrase, SchemeNode, S
 from arguebuf.models.participant import Participant
 from arguebuf.models.reference import Reference
 from arguebuf.models.resource import Resource
-from arguebuf.schema import aif, ova, sadface
+from arguebuf.schema import aif, aml, ova, sadface
 from arguebuf.services import dt, utils
 from arguebuf.services.utils import ImmutableDict, ImmutableSet
 from google.protobuf.json_format import MessageToDict, ParseDict
@@ -108,7 +109,7 @@ class Graph:
             node = self._nodes[node]
 
         incoming_nodes = list(self._incoming_nodes[node])
-        incoming_atom_nodes = set()
+        incoming_atom_nodes: set[AtomNode] = set()
 
         while incoming_nodes:
             incoming_node = incoming_nodes.pop()
@@ -131,13 +132,15 @@ class Graph:
             node = self._nodes[node]
 
         outgoing_nodes = list(self._outgoing_nodes[node])
-        outgoing_atom_nodes = set()
+        outgoing_atom_nodes: set[AtomNode] = set()
 
         while outgoing_nodes:
             outgoing_node = outgoing_nodes.pop()
 
+            # If it is an Atom, just add it to our result set
             if isinstance(outgoing_node, AtomNode):
                 outgoing_atom_nodes.add(outgoing_node)
+            # Otherwise, add the outgoing nodes of the current node to the search path
             else:
                 outgoing_nodes.extend(self._outgoing_nodes[outgoing_node])
 
@@ -737,7 +740,8 @@ class Graph:
             if edge := edge_class.from_sadface(sadface_edge, g._nodes):
                 g.add_edge(edge)
 
-        # create Metadata object
+        # create
+        # object
         created = dt.from_format(
             obj["metadata"]["core"]["created"], sadface.DATE_FORMAT
         )
@@ -919,12 +923,22 @@ class Graph:
         """Generate Graph structure from DICT argument graph file(Link?)."""
         if "analysis" in obj:
             return cls.from_ova(
-                t.cast(ova.Graph, obj), name, atom_class, scheme_class, edge_class, nlp
+                t.cast(ova.Graph, obj),
+                name,
+                atom_class,
+                scheme_class,
+                edge_class,
+                nlp,
             )
 
         if "locutions" in obj:
             return cls.from_aif(
-                t.cast(aif.Graph, obj), name, atom_class, scheme_class, edge_class, nlp
+                t.cast(aif.Graph, obj),
+                name,
+                atom_class,
+                scheme_class,
+                edge_class,
+                nlp,
             )
 
         return cls.from_protobuf(
@@ -947,7 +961,7 @@ class Graph:
     @classmethod
     def from_json(
         cls,
-        obj: t.IO,
+        obj: t.TextIO,
         name: t.Optional[str] = None,
         atom_class: t.Type[AtomNode] = AtomNode,
         scheme_class: t.Type[SchemeNode] = SchemeNode,
@@ -961,19 +975,22 @@ class Graph:
 
     def to_json(
         self,
-        obj: t.IO,
+        obj: t.TextIO,
         format: GraphFormat = GraphFormat.ARGUEBUF,
         pretty: bool = False,
     ) -> None:
         """Export structure of Graph instance to JSON argument graph format."""
         json.dump(
-            self.to_dict(format), obj, ensure_ascii=False, indent=4 if pretty else None
+            self.to_dict(format),
+            obj,
+            ensure_ascii=False,
+            indent=4 if pretty else None,
         )
 
     @classmethod
     def from_brat(
         cls,
-        obj: t.IO,
+        obj: t.TextIO,
         name: t.Optional[str] = None,
         atom_class: t.Type[AtomNode] = AtomNode,
         scheme_class: t.Type[SchemeNode] = SchemeNode,
@@ -1025,7 +1042,7 @@ class Graph:
     @classmethod
     def from_kialo(
         cls,
-        obj: t.IO,
+        obj: t.TextIO,
         name: t.Optional[str] = None,
         atom_class: t.Type[AtomNode] = AtomNode,
         scheme_class: t.Type[SchemeNode] = SchemeNode,
@@ -1114,9 +1131,40 @@ class Graph:
         return g
 
     @classmethod
-    def from_io(
+    def from_aml(
         cls,
         obj: t.IO,
+        name: t.Optional[str] = None,
+        atom_class: t.Type[AtomNode] = AtomNode,
+        scheme_class: t.Type[SchemeNode] = SchemeNode,
+        edge_class: t.Type[Edge] = Edge,
+        nlp: t.Optional[t.Callable[[str], t.Any]] = None,
+    ) -> Graph:
+        """
+        Generate Graph structure from AML argument graph file
+        ElementTree XML API: https://docs.python.org/3/library/xml.etree.elementtree.html#
+        """
+
+        tree = ET.parse(obj)
+        root = tree.getroot()
+
+        # create nodes and edges from AU element
+        au = root.find("AU")
+        g = cls(name)
+        g = aml.read_au(au, g, nlp)
+
+        # create edge objects and add to g
+
+        # create Metadata object
+        # create Analyst object
+        # create Userdata
+
+        return g
+
+    @classmethod
+    def from_io(
+        cls,
+        obj: t.TextIO,
         suffix: str,
         name: t.Optional[str] = None,
         atom_class: t.Type[AtomNode] = AtomNode,
@@ -1131,12 +1179,14 @@ class Graph:
             return cls.from_brat(*args)
         if suffix == ".txt":
             return cls.from_kialo(*args)
+        if suffix == ".aml":
+            return cls.from_aml(*args)
 
         return cls.from_json(*args)
 
     def to_io(
         self,
-        obj: t.IO,
+        obj: t.TextIO,
         format: GraphFormat = GraphFormat.ARGUEBUF,
         pretty: bool = False,
     ) -> None:
@@ -1158,7 +1208,13 @@ class Graph:
 
         with path.open("r", encoding="utf-8") as file:
             return cls.from_io(
-                file, path.suffix, path.stem, atom_class, scheme_class, edge_class, nlp
+                file,
+                path.suffix,
+                path.stem,
+                atom_class,
+                scheme_class,
+                edge_class,
+                nlp,
             )
 
     def to_file(
@@ -1293,7 +1349,7 @@ class Graph:
         edge_attr: t.Optional[t.Mapping[str, str]] = None,
     ) -> gv.Digraph:
         """Transform a Graph instance into an instance of GraphViz directed graph. Make sure that a GraphViz Executable path is set on your machine for visualization. Refer to the GraphViz library for additional information."""
-        gv_margin = lambda x: f"{x[0]},{x[1]}"
+        gv_margin: t.Callable[[t.Tuple[float, float]], str] = lambda x: f"{x[0]},{x[1]}"
 
         if not graph_attr:
             graph_attr = {}
@@ -1313,14 +1369,15 @@ class Graph:
                 "fontname": font_name or "Arial",
                 "fontsize": str(font_size or 11),
                 "margin": gv_margin(margin or (0.15, 0.1)),
-                "style": "filled",
+                "style": "rounded,filled",
                 "shape": "box",
                 "width": "0",
                 "height": "0",
                 **node_attr,
             },
-            edge_attr={"color": "#666666", **edge_attr},
+            edge_attr={"color": "#9E9E9E", **edge_attr},
             graph_attr={
+                # "bgcolor": "#000000",
                 "rankdir": "BT",
                 "margin": "0",
                 "nodesep": str(nodesep or 0.25),
@@ -1340,7 +1397,7 @@ class Graph:
         for node in self._scheme_nodes.values():
             node.to_gv(
                 g,
-                self.major_claim == node,
+                False,
                 label_func=scheme_label,
                 wrap_col=wrap_col or 36,
             )
@@ -1363,17 +1420,14 @@ class Graph:
 
         for scheme in schemes:
             for incoming, outgoing in itertools.product(
-                self._incoming_edges[scheme], self._outgoing_edges[scheme]
+                self.incoming_atom_nodes(scheme), self.outgoing_atom_nodes(scheme)
             ):
-                if isinstance(incoming.source, AtomNode) and isinstance(
-                    outgoing.target, AtomNode
-                ):
-                    self.add_edge(
-                        Edge(
-                            incoming.source,
-                            outgoing.target,
-                        )
+                self.add_edge(
+                    Edge(
+                        incoming,
+                        outgoing,
                     )
+                )
 
             self.remove_node(scheme)
 
