@@ -2,8 +2,9 @@ from __future__ import absolute_import, annotations
 
 import textwrap
 import typing as t
+import xml.etree.ElementTree as et
 from abc import ABC, abstractmethod
-from dataclasses import dataclass
+from dataclasses import dataclass, field
 from enum import Enum
 
 import graphviz as gv
@@ -24,7 +25,7 @@ NO_SCHEME_LABEL = "Unknown"
 class Support(Enum):
     """Enumeration of all available Argumentation Schemes (Walton et al.)
 
-    .. autoclasssumm:: Scheme
+    .. autoclasssumm:: Support
         :autosummary-sections: Methods
     """
 
@@ -100,14 +101,32 @@ class Support(Enum):
 
 
 class Attack(Enum):
+    """Enumeration of attacking schemes
+
+    .. autoclasssumm:: Attack
+        :autosummary-sections: Methods
+    """
+
     DEFAULT = "Default"
 
 
 class Preference(Enum):
+    """Enumeration of preference schemes
+
+    .. autoclasssumm:: Preference
+        :autosummary-sections: Methods
+    """
+
     DEFAULT = "Default"
 
 
 class Rephrase(Enum):
+    """Enumeration of rephrase schemes
+
+    .. autoclasssumm:: Rephrase
+        :autosummary-sections: Methods
+    """
+
     DEFAULT = "Default"
 
 
@@ -263,16 +282,26 @@ text2scheme: t.Dict[
 
 @dataclass
 class Color:
-    bg: str = "#ffffff"
-    fg: str = "#000000"
-    border: str = "#000000"
+    bg: str
+    fg: str
+    border: str
+
+    def __init__(
+        self,
+        bg: t.Optional[str] = None,
+        fg: t.Optional[str] = None,
+        border: t.Optional[str] = None,
+    ) -> None:
+        self.bg = bg or "#000000"
+        self.fg = fg or "#ffffff"
+        self.border = border or self.bg
 
 
 scheme2color: t.Dict[t.Type[Scheme], Color] = {
-    Support: Color(bg="#def8e9", border="#2ecc71"),
-    Attack: Color(bg="#fbdedb", border="#e74c3c"),
-    Rephrase: Color(bg="#fbeadb", border="#e67e22"),
-    Preference: Color(bg="#dcfaf4", border="#1abc9c"),
+    Support: Color(bg="#4CAF50"),
+    Attack: Color(bg="#F44336"),
+    Rephrase: Color(bg="#009688"),
+    Preference: Color(bg="#009688"),
 }
 
 
@@ -336,6 +365,15 @@ class Node(ABC):
     ) -> Node:
         """Generate Node object from SADFace Node format."""
 
+    @classmethod
+    @abstractmethod
+    def from_aml(
+        cls,
+        obj: et.Element,
+        nlp: t.Optional[t.Callable[[str], t.Any]] = None,
+    ) -> Node:
+        """Generate Node object from AML Node format."""
+
     @abstractmethod
     def to_aif(self) -> aif.Node:
         """Export Node object into AIF Node format."""
@@ -358,7 +396,11 @@ class Node(ABC):
         """Export Node object into PROTOBUF Node object."""
 
     @abstractmethod
-    def to_nx(self, g: nx.DiGraph, label_attr: t.Optional[str] = None) -> None:
+    def to_nx(
+        self,
+        g: nx.DiGraph,
+        attrs: t.Optional[t.MutableMapping[str, t.Callable[[Node], t.Any]]] = None,
+    ) -> None:
         """Submethod used to export Graph object g into NX Graph format."""
 
     @abstractmethod
@@ -426,6 +468,45 @@ class AtomNode(Node):
             metadata=Metadata(timestamp, timestamp),
         )
 
+    @classmethod
+    def from_aml(
+        cls,
+        obj: et.Element,
+        nlp: t.Optional[t.Callable[[str], t.Any]] = None,
+    ) -> AtomNode:
+        """
+        Generate Node object from AML Node format. obj is a AML "PROP" element.
+        """
+        # get id of PROP
+        if "identifier" in obj.attrib:
+            id = obj.get("identifier")
+        else:
+            id = None
+
+        # read text of PROP
+        text = obj.find("PROPTEXT").text
+
+        # read owners of PROP
+        owner_list = obj.findall("OWNER")
+        owners_lst = []
+        if not owner_list:
+            # if not empty, do something
+            for owner in owner_list:
+                owners_lst.append(owner.get("name"))
+            owners = {"owners": ", ".join(owners_lst)}
+        else:
+            owners = {}
+
+        # create timestamp
+        timestamp = pendulum.now()
+
+        return cls(
+            id=id,
+            text=utils.parse(text, nlp),
+            metadata=Metadata(timestamp, timestamp),
+            userdata=owners,
+        )
+
     @classmethod
     def from_aif(
         cls,
@@ -519,9 +600,9 @@ class AtomNode(Node):
     def color(self, major_claim: bool) -> Color:
         """Get the color for rendering the node."""
         if major_claim:
-            return Color(bg="#3498db", border="#3498db")
+            return Color(bg="#0D47A1")
 
-        return Color(bg="#ddeef9", border="#3498db")
+        return Color(bg="#2196F3")
 
     def to_gv(
         self,
@@ -589,16 +670,18 @@ class SchemeNode(Node):
     ) -> SchemeNode:
         """Generate SchemeNode object from SADFace Node object."""
         name = None
+
         if obj["name"] == "support":
-            name = Support
+            name = Support.DEFAULT
         elif obj["name"] == "attack":
-            name = Attack
+            name = Attack.DEFAULT
         elif obj["name"] == "rephrase":
-            name = Rephrase
+            name = Rephrase.DEFAULT
         elif obj["name"] == "preference":
-            name = Preference
+            name = Preference.DEFAULT
 
         timestamp = pendulum.now()
+
         return cls(
             id=obj["id"],
             userdata=obj["metadata"],
@@ -606,6 +689,64 @@ class SchemeNode(Node):
             scheme=name,
         )
 
+    @classmethod
+    def from_aml(
+        cls,
+        obj: et.Element,
+        nlp: t.Optional[t.Callable[[str], t.Any]] = None,
+        refutation=False,
+    ) -> SchemeNode:
+        """Generate SchemeNode object from AML Node format. obj is a AML "PROP" element."""
+
+        # get id of PROP
+        if "identifier" in obj.attrib:
+            id = obj.get("identifier")
+        else:
+            id = None
+
+        # read owners of PROP
+        owner_list = obj.findall("OWNER")
+        owners_lst = []
+        if not owner_list:
+            # if not empty, do something
+            for owner in owner_list:
+                owners_lst.append(owner.get("name"))
+            owners = {"owners": ", ".join(owners_lst)}
+        else:
+            owners = {}
+
+        # create timestamp
+        timestamp = pendulum.now()
+
+        # get scheme name
+        scheme = None
+        if refutation:
+            scheme = Attack.DEFAULT
+        else:
+            inscheme = obj.find("INSCHEME")
+            if inscheme is not None:  # if INSCHEME element is available
+                # get scheme
+                aml_scheme = inscheme.attrib["scheme"]
+                contains_scheme = False
+                for supp_scheme in Support:
+                    if supp_scheme.value.lower().replace(
+                        " ", ""
+                    ) in aml_scheme.lower().replace(" ", ""):
+                        scheme = supp_scheme
+                        contains_scheme = True
+                        break
+                if not contains_scheme:
+                    scheme = Support.DEFAULT
+            else:  # if INSCHEME element is not available
+                scheme = Support.DEFAULT
+
+        return cls(
+            metadata=Metadata(timestamp, timestamp),
+            scheme=scheme,
+            userdata=owners,
+            id=id,
+        )
+
     @classmethod
     def from_aif(
         cls,
@@ -756,11 +897,7 @@ class SchemeNode(Node):
     def color(self, major_claim: bool) -> Color:
         """Get the color used in OVA based on `category`."""
 
-        return (
-            scheme2color[type(self.scheme)]
-            if self.scheme
-            else Color(bg="#e9eded", border="#95a5a6")
-        )
+        return scheme2color[type(self.scheme)] if self.scheme else Color(bg="#e9eded")
 
     def to_gv(
         self,
